==> kdegames-3.1.3-i386-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkdegames.so.1 )
( cd opt/kde/lib ; ln -sf libkdegames.so.1.1.0 libkdegames.so.1 )
( cd opt/kde/lib ; rm -rf libkdegames.so )
( cd opt/kde/lib ; ln -sf libkdegames.so.1.1.0 libkdegames.so )
( cd opt/kde/lib ; rm -rf libatlantic.so )
( cd opt/kde/lib ; ln -sf libatlantic.so.1.1.0 libatlantic.so )
( cd opt/kde/lib ; rm -rf libatlantic.so.1 )
( cd opt/kde/lib ; ln -sf libatlantic.so.1.1.0 libatlantic.so.1 )
( cd opt/kde/lib ; rm -rf libatlantikclient.so )
( cd opt/kde/lib ; ln -sf libatlantikclient.so.1.1.0 libatlantikclient.so )
( cd opt/kde/lib ; rm -rf libatlantikui.so )
( cd opt/kde/lib ; ln -sf libatlantikui.so.1.1.0 libatlantikui.so )
( cd opt/kde/lib ; rm -rf libkolf.so.0 )
( cd opt/kde/lib ; ln -sf libkolf.so.0.0.0 libkolf.so.0 )
( cd opt/kde/lib ; rm -rf libkolf.so )
( cd opt/kde/lib ; ln -sf libkolf.so.0.0.0 libkolf.so )
( cd opt/kde/lib ; rm -rf libatlantikclient.so.1 )
( cd opt/kde/lib ; ln -sf libatlantikclient.so.1.1.0 libatlantikclient.so.1 )
( cd opt/kde/lib ; rm -rf libatlantikui.so.1 )
( cd opt/kde/lib ; ln -sf libatlantikui.so.1.1.0 libatlantikui.so.1 )
( cd opt/kde/share/doc/HTML/en/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktuberling ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kolf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/katomic ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbounce ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksame ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktron ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kwin4 ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/lskat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kshisen ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksirtet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konquest ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kasteroids ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/klines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpoker ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksnake ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/megami ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/megami ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kreversi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/klickety ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kenolaba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksokoban ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/atlantik ; ln -sf /opt/kde/share/doc/HTML/en/common common )

==> kdegames-3.2.3-i486-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkdegames.so.1 )
( cd opt/kde/lib ; ln -sf libkdegames.so.1.2.0 libkdegames.so.1 )
( cd opt/kde/lib ; rm -rf libkdegames.so )
( cd opt/kde/lib ; ln -sf libkdegames.so.1.2.0 libkdegames.so )
( cd opt/kde/lib ; rm -rf libatlantic.so )
( cd opt/kde/lib ; ln -sf libatlantic.so.1.2.0 libatlantic.so )
( cd opt/kde/lib ; rm -rf libatlantic.so.1 )
( cd opt/kde/lib ; ln -sf libatlantic.so.1.2.0 libatlantic.so.1 )
( cd opt/kde/lib ; rm -rf libatlantikclient.so )
( cd opt/kde/lib ; ln -sf libatlantikclient.so.1.2.0 libatlantikclient.so )
( cd opt/kde/lib ; rm -rf libatlantikui.so )
( cd opt/kde/lib ; ln -sf libatlantikui.so.1.2.0 libatlantikui.so )
( cd opt/kde/lib ; rm -rf libkolf.so.1 )
( cd opt/kde/lib ; ln -sf libkolf.so.1.2.0 libkolf.so.1 )
( cd opt/kde/lib ; rm -rf libkolf.so )
( cd opt/kde/lib ; ln -sf libkolf.so.1.2.0 libkolf.so )
( cd opt/kde/lib ; rm -rf libatlantikclient.so.1 )
( cd opt/kde/lib ; ln -sf libatlantikclient.so.1.2.0 libatlantikclient.so.1 )
( cd opt/kde/lib ; rm -rf libatlantikui.so.1 )
( cd opt/kde/lib ; ln -sf libatlantikui.so.1.2.0 libatlantikui.so.1 )
( cd opt/kde/share/doc/HTML/en/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktuberling ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kolf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/katomic ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbounce ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksame ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktron ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kwin4 ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/lskat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kshisen ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksirtet ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konquest ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kasteroids ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/klines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpoker ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksnake ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kreversi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/klickety ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kenolaba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksokoban ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdegames-apidocs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdegames-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/atlantik ; ln -sf /opt/kde/share/doc/HTML/en/common common )
